<?php
defined( 'ABSPATH' ) OR exit;
/**
 * Plugin Name: Facebook Comment Slider
 * Plugin URI: http://facebookslider.pantherius.com
 * Description: Offer an option for the users to leave comment about your website after they reach the bottom of the page
 * Author: Pantherius
 * Version: 1.8.6
 * Author URI: http://pantherius.com
 */
 
define( 'FB_COMMENT_SLIDER_TEXT_DOMAIN' , 'facebook_comment_slider' );
define( 'FB_COMMENT_SLIDER_VERSION' , '1.8.6' ); 
 
if ( ! class_exists( 'facebook_comment_slider' ) ) {
	class facebook_comment_slider {
		public static $inserted = 0;
		protected static $instance = null;
		/**
		 * Construct the plugin object
		 */
		public function __construct()
		{
			// installation and uninstallation hooks
			register_activation_hook(__FILE__, array('facebook_comment_slider', 'activate'));
			register_deactivation_hook(__FILE__, array('facebook_comment_slider', 'deactivate'));
			register_uninstall_hook(__FILE__, array('facebook_comment_slider', 'uninstall'));
			add_action( 'plugins_loaded', array(&$this, 'facebook_comment_slider_localization'));
			add_filter( 'wp_footer', array(&$this, 'check_404') );
			if (is_admin())
			{
				require_once(sprintf("%s/settings.php", dirname(__FILE__)));
				$facebook_comment_slider_settings = new facebook_comment_slider_settings();
				$plugin = plugin_basename(__FILE__);
				add_filter("plugin_action_links_$plugin", array(&$this, 'plugin_settings_link'));
				add_action('wp_ajax_ajax_fbcs', array(&$this, 'ajax_fbcs'));
				add_action('wp_ajax_nopriv_ajax_fbcs', array(&$this, 'ajax_fbcs'));
			}
			else
			{
					if (!facebook_comment_slider::is_login_page())
					{
					//integrate the content modifier function
					add_filter('the_content',array(&$this, 'extend_the_content'));
					add_shortcode( "enable_facebook_comment_slider", array( &$this, "enable_facebook_comment_slider" ) );
					add_shortcode( "likebox_facebook_comment_slider", array( &$this, "likebox_facebook_comment_slider" ) );
					add_shortcode( "postbox_facebook_comment_slider", array( &$this, "postbox_facebook_comment_slider" ) );
					add_shortcode( "disable_facebook_comment_slider", array( &$this, "disable_facebook_comment_slider" ) );
					add_shortcode( "likebox_facebook_comment_slider_embed", array( &$this, "likebox_facebook_comment_slider_embed" ) );
					add_shortcode( "postbox_facebook_comment_slider_embed", array( &$this, "postbox_facebook_comment_slider_embed" ) );
					add_shortcode( "facebook_comment_slider_embed", array( &$this, "facebook_comment_slider_embed" ) );
					if (get_option('setting_onlyposts')=='on') add_action( 'wp_print_scripts', array(&$this, 'enqueue_custom_scripts_and_styles'));
					else
					{
					if (get_option('setting_display_only_allowed_pages')!='on') add_action('init', array(&$this, 'enqueue_custom_scripts_and_styles'));
					}
					if (get_option('setting_appid')) add_action('wp_head', array(&$this, 'add_meta_appid'));
					if (get_option('setting_adminid')) add_action('wp_head', array(&$this, 'add_meta_fbadmin'));
					}
			}
		}
		public function enable_facebook_comment_slider( $atts ) {
			return "<div class='facebook-comment-slider-shortcode' style='display: none'>[enable_facebook_comment_slider]</div>";
		}
		public function likebox_facebook_comment_slider( $atts ) {
			return "<div class='facebook-comment-slider-shortcode' style='display: none'>[likebox_facebook_comment_slider]</div>";
		}
		public function postbox_facebook_comment_slider( $atts ) {
			return "<div class='facebook-comment-slider-shortcode' style='display: none'>[postbox_facebook_comment_slider]</div>";
		}
		public function disable_facebook_comment_slider( $atts ) {
			return "<div class='facebook-comment-slider-shortcode' style='display: none'>[disable_facebook_comment_slider]</div>";
		}
		public function likebox_facebook_comment_slider_embed( $atts ) {
			$atts = shortcode_atts( array(
					'align' => 'center'
				), $atts, 'likebox_facebook_comment_slider_embed' );
			return "<div class='facebook-comment-slider-likebox-embed " . $atts[ 'align' ] . "'></div>";
		}
		public function postbox_facebook_comment_slider_embed( $atts ) {
			$atts = shortcode_atts( array(
					'align' => 'center'
				), $atts, 'likebox_facebook_comment_slider_embed' );
			return "<div class='facebook-comment-slider-postbox-embed " . $atts[ 'align' ] . "'></div>";
		}
		public function facebook_comment_slider_embed( $atts ) {
			$atts = shortcode_atts( array(
					'align' => 'center'
				), $atts, 'likebox_facebook_comment_slider_embed' );
			return "<div class='facebook-comment-slider-embed " . $atts[ 'align' ] . "'></div>";
		}
		function check_404( $title ) {
			if (is_404()) print('<div style="display:none">[disable_facebook_comment_slider]</div>');
		}
		public static function getInstance()
		{
			if (!isset($instance)) 
			{
				$instance = new facebook_comment_slider;
			}
		return $instance;
		}
		/**
		* Activate the plugin
		**/
		public static function activate()
		{
			if ( ! get_option('setting_hide_icon'))
			{
				add_option('setting_hide_icon' , 'off');
			}
			if ( ! get_option('setting_icon_size1'))
			{
				add_option('setting_icon_size1' , 'large');
			}
			if ( ! get_option('setting_icon_size2'))
			{
				add_option('setting_icon_size2' , 'large');
			}
			if ( ! get_option('setting_icon_size3'))
			{
				add_option('setting_icon_size3' , 'large');
			}
			if ( ! get_option('setting_auto_open1'))
			{
				add_option('setting_auto_open1' , 'on');
			}
			if ( ! get_option('setting_auto_open2'))
			{
				add_option('setting_auto_open2' , 'on');
			}
			if ( ! get_option('setting_auto_open3'))
			{
				add_option('setting_auto_open3' , 'on');
			}
			if ( ! get_option('setting_lock_screen'))
			{
				add_option('setting_lock_screen' , 'on');
			}
			if ( ! get_option('setting_closeable'))
			{
				add_option('setting_closeable' , 'on');
			}
			if ( ! get_option('setting_timer'))
			{
				add_option('setting_timer' , '300sec');
			}
			if ( ! get_option('setting_icontime'))
			{
				add_option('setting_icontime' , '0sec');
			}
			if ( ! get_option('setting_transparency'))
			{
				add_option('setting_transparency' , '90%');
			}
			if ( ! get_option('setting_message'))
			{
				add_option('setting_message' , 'Please leave a comment');
			}
			if ( ! get_option('setting_likebox_message'))
			{
				add_option('setting_likebox_message' , 'Like Our Facebook Page');
			}
			if ( ! get_option('setting_postbox_message'))
			{
				add_option('setting_postbox_message' , 'Follow Us on Facebook!');
			}
			if ( ! get_option('setting_display_once_for_same_user'))
			{
				add_option('setting_display_once_for_same_user' , 'off');
			}
			if ( ! get_option('setting_disable_on_mobile'))
			{
				add_option('setting_disable_on_mobile' , 'off');
			}
			if ( ! get_option('setting_onlyposts'))
			{
				add_option('setting_onlyposts' , 'off');
			}
			if ( ! get_option('setting_display_only_allowed_pages'))
			{
				add_option('setting_display_only_allowed_pages' , 'off');
			}
			if ( ! get_option('setting_localization'))
			{
				add_option('setting_localization' , 'en_US');
			}
			if ( ! get_option('setting_specified_page1'))
			{
				add_option('setting_specified_page1' , 'all');
			}
			if ( ! get_option('setting_direction1'))
			{
				add_option('setting_direction1' , 'left');
			}
			if ( ! get_option('setting_direction2'))
			{
				add_option('setting_direction2' , 'left');
			}
			if ( ! get_option('setting_direction3'))
			{
				add_option('setting_direction3' , 'left');
			}
			if ( ! get_option('setting_no_post_to_show'))
			{
				add_option('setting_no_post_to_show' , '5');
			}
			if ( ! get_option('setting_vertical_distance1'))
			{
				add_option('setting_vertical_distance1' , '50%');
			}
			if ( ! get_option('setting_vertical_distance2'))
			{
				add_option('setting_vertical_distance2' , '20%');
			}
			if ( ! get_option('setting_vertical_distance3'))
			{
				add_option('setting_vertical_distance3' , '80%');
			}
			if ( ! get_option('setting_home_page_style'))
			{
				add_option('setting_home_page_style' , 'likebox');
			}
			if ( ! get_option('setting_applyhome'))
			{
				add_option('setting_applyhome' , 'no');
			}
			if ( ! get_option('setting_keep_settings'))
			{
				add_option('setting_keep_settings' , 'off');
			}
			if ( ! get_option('setting_notification_email'))
			{
				add_option('setting_notification_email' , '');
			}
			if ( ! get_option( 'setting_fbclcustomcss' ) ) {
				add_option( 'setting_fbclcustomcss' , '' );
			}
			if ( ! get_option( 'setting_minify_scripts' ) ) {
				add_option( 'setting_minify_scripts' , 'on' );
			}
		}
		//Check it is a login or registration page
		function is_login_page() {
			return in_array($GLOBALS['pagenow'], array('wp-login.php', 'wp-register.php'));
		}
		/**
		* Adding extra content to the main content - fbshare, gplus, gmaps, etc.
		**/
		function extend_the_content($content)
		{
		global $post;
			if ( get_option( 'setting_display_only_allowed_pages' ) == 'on' ) {
				if ( ( strpos( $content, '[enable_facebook_comment_slider]') !== false ) || ( strpos( $content, '[likebox_facebook_comment_slider]') !== false ) || ( strpos( $content, '[postbox_facebook_comment_slider]') !== false ) ) {
					$this->enqueue_custom_scripts_and_styles();
				}
			}
			if ( get_option( 'setting_specified_page1' ) == 'posts' ) {
				if ( ! is_single() && facebook_comment_slider::$inserted == 0 && ! is_feed() ) {
					$content .= "[disable_facebook_comment_slider]";
					facebook_comment_slider::$inserted++;
				}
			}
			elseif ( get_option( 'setting_specified_page1' ) == 'pages' ) {
				if ( ! is_page() && facebook_comment_slider::$inserted == 0 && ! is_feed() ) {
					$content .= "[disable_facebook_comment_slider]";
					facebook_comment_slider::$inserted++;
				}
			}
			elseif ( get_option( 'setting_specified_page1' ) == 'both' ) {
				if ( ! is_single() && ! is_page() && facebook_comment_slider::$inserted == 0 && ! is_feed() ) {
					$content .= "[disable_facebook_comment_slider]";
					facebook_comment_slider::$inserted++;
				}
			}
		return $content;
		}
		/**
		* Deactivate the plugin
		**/
		public static function deactivate()
		{
			unregister_setting('facebook_comment_slider-group', 'setting_appid');
			unregister_setting('facebook_comment_slider-group', 'setting_adminid');
			unregister_setting('facebook_comment_slider-group', 'setting_fbsitename');
			unregister_setting('facebook_comment_slider-group', 'setting_home_page_style');
			unregister_setting('facebook_comment_slider-group', 'setting_applyhome');
			unregister_setting('facebook_comment_slider-group', 'setting_hide_icon');
			unregister_setting('facebook_comment_slider-group', 'setting_lock_screen');
			unregister_setting('facebook_comment_slider-group', 'setting_closeable');
			unregister_setting('facebook_comment_slider-group', 'setting_timer');
			unregister_setting('facebook_comment_slider-group', 'setting_icontime');
			unregister_setting('facebook_comment_slider-group', 'setting_transparency');
			unregister_setting('facebook_comment_slider-group', 'setting_display_once_for_same_user');
			unregister_setting('facebook_comment_slider-group', 'setting_disable_on_mobile');
			unregister_setting('facebook_comment_slider-group', 'setting_onlyposts');
			unregister_setting('facebook_comment_slider-group', 'setting_display_only_allowed_pages');
			unregister_setting('facebook_comment_slider-group', 'setting_localization');
			unregister_setting('facebook_comment_slider-group', 'setting_scheme');
			unregister_setting('facebook_comment_slider-group', 'setting_skin');
			unregister_setting('facebook_comment_slider-group', 'setting_hide_alreadyliked');
			unregister_setting('facebook_comment_slider-group', 'setting_keep_settings');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_vertical_distance1');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_icon_size1');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_auto_open1');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_message');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_specified_page1');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_direction1');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_no_post_to_show');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_icon_url1');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_shake1');
			unregister_setting('facebook_comment_slider_comment_box-group', 'setting_notification_email');
			unregister_setting('facebook_comment_slider_like_box-group', 'setting_vertical_distance2');
			unregister_setting('facebook_comment_slider_like_box-group', 'setting_icon_size2');
			unregister_setting('facebook_comment_slider_like_box-group', 'setting_auto_open2');
			unregister_setting('facebook_comment_slider_like_box-group', 'setting_likebox_message');
			unregister_setting('facebook_comment_slider_like_box-group', 'setting_direction2');
			unregister_setting('facebook_comment_slider_like_box-group', 'setting_icon_url2');
			unregister_setting('facebook_comment_slider_like_box-group', 'setting_shake2');
			unregister_setting('facebook_comment_slider_post_box-group', 'setting_vertical_distance3');
			unregister_setting('facebook_comment_slider_post_box-group', 'setting_icon_size3');
			unregister_setting('facebook_comment_slider_post_box-group', 'setting_auto_open3');
			unregister_setting('facebook_comment_slider_post_box-group', 'setting_postbox_message');
			unregister_setting('facebook_comment_slider_post_box-group', 'setting_direction3');
			unregister_setting('facebook_comment_slider_post_box-group', 'setting_icon_url3');
			unregister_setting('facebook_comment_slider_post_box-group', 'setting_shake3');
			unregister_setting('facebook_comment_slider_customcss-group', 'setting_fbclcustomcss');
		}
		
		/**
		* Uninstall the plugin
		**/
		public static function uninstall()
		{
			if (get_option('setting_keep_settings')!='on')
			{
				delete_option('setting_appid');
				delete_option('setting_adminid');
				delete_option('setting_fbsitename');
				delete_option('setting_home_page_style');
				delete_option('setting_applyhome');
				delete_option('setting_hide_icon');
				delete_option('setting_lock_screen');
				delete_option('setting_closeable');
				delete_option('setting_timer');
				delete_option('setting_icontime');
				delete_option('setting_transparency');
				delete_option('setting_display_once_for_same_user');
				delete_option('setting_disable_on_mobile');
				delete_option('setting_keep_settings');
				delete_option('setting_onlyposts');
				delete_option('setting_display_only_allowed_pages');
				delete_option('setting_localization');
				delete_option('setting_scheme');
				delete_option('setting_skin');
				delete_option('setting_hide_alreadyliked');
				delete_option('setting_vertical_distance1');
				delete_option('setting_icon_size1');
				delete_option('setting_auto_open1');
				delete_option('setting_message');
				delete_option('setting_specified_page1');
				delete_option('setting_direction1');
				delete_option('setting_no_post_to_show');
				delete_option('setting_icon_url1');
				delete_option('setting_shake1');
				delete_option('setting_notification_email');
				delete_option('setting_vertical_distance2');
				delete_option('setting_icon_size2');
				delete_option('setting_auto_open2');
				delete_option('setting_likebox_message');
				delete_option('setting_direction2');
				delete_option('setting_icon_url2');
				delete_option('setting_shake2');
				delete_option('setting_vertical_distance3');
				delete_option('setting_icon_size3');
				delete_option('setting_auto_open3');
				delete_option('setting_postbox_message');
				delete_option('setting_direction3');
				delete_option('setting_icon_url3');
				delete_option('setting_shake3');
				delete_option('setting_fbclcustomcss');
			}
		}

		/**
		* Enable Localization
		**/
		public function facebook_comment_slider_localization() {
		// Localization
		load_plugin_textdomain( 'facebook_comment_slider', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
		}
		
		function add_meta_appid()
		{
			return print('<meta property="fb:app_id" content="'.get_option('setting_appid').'">');
		}
		
		function add_meta_fbadmin()
		{
			return print('<meta property="fb:admins" content="'.get_option('setting_adminid').'"/>');
		}
		
		function enqueue_custom_scripts_and_styles() 
		{
		if (get_option('setting_onlyposts')=='on') {if (!is_single()) return true;}
		$direction = '';$domain = '';
		if (get_option('setting_direction1')=='right') $direction1 = 'right';
		else $direction1 = 'left';
		if (get_option('setting_direction2')=='right') $direction2 = 'right';
		else $direction2 = 'left';
		if (get_option('setting_direction3')=='right') $direction3 = 'right';
		else $direction3 = 'left';
		if (get_option('setting_closeable')=='on') $closeable = 'true';
		else $closeable = 'false';
		if (get_option('setting_hide_icon')=='off') $hide_icon = 'false';
		else $hide_icon = 'true';
		if (get_option('setting_icon_size1')) $icon_size1 = get_option('setting_icon_size1');
		else $icon_size1 = 'medium';
		if (get_option('setting_icon_size2')) $icon_size2 = get_option('setting_icon_size2');
		else $icon_size2 = 'medium';
		if (get_option('setting_icon_size3')) $icon_size3 = get_option('setting_icon_size3');
		else $icon_size3 = 'medium';
		if (get_option('setting_auto_open1')=='off') $auto_open1 = 'false';
		else $auto_open1 = 'true';
		if (get_option('setting_auto_open2')=='off') $auto_open2 = 'false';
		else $auto_open2 = 'true';
		if (get_option('setting_auto_open3')=='off') $auto_open3 = 'false';
		else $auto_open3 = 'true';
		if (get_option('setting_lock_screen')=='on') $lock_screen = 'true';
		else $lock_screen = 'false';
		if (get_option('setting_timer')>0) $timer = get_option('setting_timer');
		if (get_option('setting_icontime')>=0) $icontime = get_option('setting_icontime')*1000;
		else {
			$icontime = 1500;
		}
		if (get_option('setting_transparency')>=0) $transparency = get_option('setting_transparency');
		else $transparency = '90';
		if (get_option('setting_message')) $message = get_option('setting_message');
		else $message = 'Please leave a comment';
		if (get_option('setting_postbox_message')) $postbox_message = get_option('setting_postbox_message');
		else $postbox_message = 'Like Our Facebook Page';
		if (get_option('setting_likebox_message')) $likebox_message = get_option('setting_likebox_message');
		else $likebox_message = 'Follow Us on Facebook';
		if (get_option('setting_display_once_for_same_user')=='on') $dofsu = 'true';
		else $dofsu = 'false';
		if (get_option('setting_disable_on_mobile')=='on') $dom = 'true';
		else $dom = 'false';
		if (get_option('setting_display_only_allowed_pages')=='on') $doap = 'true';
		else $doap = 'false';
		if (get_option('setting_no_post_to_show')>0) $no_post_to_show = get_option('setting_no_post_to_show');
		else $no_post_to_show = 5;
		if (get_option('setting_localization')) $local = get_option('setting_localization');
		else $local = 'en_US';
		if (get_option('setting_appid')) $appid = get_option('setting_appid');
		else $appid = 'false';
		if (get_option('setting_scheme')) $scheme = get_option('setting_scheme');
		else $scheme = 'light';
		if (get_option('setting_skin')) $skin = get_option('setting_skin');
		else $skin = 'default';
		if (get_option('setting_hide_alreadyliked')=='on') $hal = true;
		else $hal = false;
		if (get_option('setting_shake1')) $shake1 = get_option('setting_shake1');
		else $shake1 = '0';
		if (get_option('setting_shake2')) $shake2 = get_option('setting_shake2');
		else $shake2 = '0';
		if (get_option('setting_shake3')) $shake3 = get_option('setting_shake3');
		else $shake3 = '0';
		if (get_option('setting_icon_url1')) $icon_url1 = get_option('setting_icon_url1');
		else $icon_url1 = '';
		if (get_option('setting_icon_url2')) $icon_url2 = get_option('setting_icon_url2');
		else $icon_url2 = '';
		if (get_option('setting_icon_url3')) $icon_url3 = get_option('setting_icon_url3');
		else $icon_url3 = '';
		if (get_option('setting_vertical_distance1')) $vertical_distance1 = str_replace( "%", "", get_option( 'setting_vertical_distance1' ) );
		else $vertical_distance1 = '50';
		if (get_option('setting_vertical_distance2')) $vertical_distance2 = str_replace( "%", "", get_option('setting_vertical_distance2' ) );
		else $vertical_distance2 = '30';
		if (get_option('setting_vertical_distance3')) $vertical_distance3 = str_replace( "%", "", get_option('setting_vertical_distance3' ) );
		else $vertical_distance3 = '80';
		if (get_option('setting_home_page_style')) $home_page_style = get_option('setting_home_page_style');
		else $home_page_style = 'likebox';
		if (get_option('setting_fbsitename')) $fbsitename = get_option('setting_fbsitename');
		else $fbsitename = '';
		if (isset($_SERVER['HTTP_HOST']) AND isset($_SERVER['REQUEST_URI'])) $domain = 'http://'.$_SERVER['HTTP_HOST'].$_SERVER['REQUEST_URI'];
		else $domain = get_permalink();
		$channel_url = plugins_url( '/templates/channel.html' , __FILE__ );
		$xid = md5($domain);

		/* params for demo start */
		if (isset($_REQUEST['s_direction'])) $direction1 = $_REQUEST['s_direction'];
		if (isset($_REQUEST['s_closeable'])) $closeable = $_REQUEST['s_closeable'];
		if (isset($_REQUEST['s_hide_icon'])) $hide_icon = $_REQUEST['s_hide_icon'];
		if (isset($_REQUEST['s_icon_size'])) $icon_size1 = $_REQUEST['s_icon_size'];
		if (isset($_REQUEST['s_auto_open'])) $auto_open1 = $_REQUEST['s_auto_open'];
		if (isset($_REQUEST['s_lock_screen'])) $lock_screen = $_REQUEST['s_lock_screen'];
		if (isset($_REQUEST['s_timer'])) $timer = $_REQUEST['s_timer'];
		if (isset($_REQUEST['s_icontime'])) $icontime = $_REQUEST['s_icontime'];
		if (isset($_REQUEST['s_transparency'])) $transparency = $_REQUEST['s_transparency'];
		if (isset($_REQUEST['s_message'])) $message = $_REQUEST['s_message'];
		if (isset($_REQUEST['s_localization'])) $local = $_REQUEST['s_localization'];
		if (isset($_REQUEST['s_scheme'])) $scheme = $_REQUEST['s_scheme'];
		if (isset($_REQUEST['s_shake'])) $shake1 = $_REQUEST['s_shake'];
		if (isset($_REQUEST['s_vertical'])) $vertical_distance1 = $_REQUEST['s_vertical'];
		if (isset($_REQUEST['s_icon_url'])) $icon_url1 = $_REQUEST['s_icon_url'];
		if (isset($_REQUEST['s_skin'])) $skin = $_REQUEST['s_skin'];
		
		/* params for demo end */
		$currentstyle = "";
		if ('http://'.$_SERVER['HTTP_HOST'].'/'==$domain||'http://'.$_SERVER['HTTP_HOST']==$domain||'http://www.'.$_SERVER['HTTP_HOST']==$domain||'http://www.'.$_SERVER['HTTP_HOST'].'/'==$domain) $currentstyle = "home";
		else $currentstyle = "";
		if ( get_option( "setting_minify_scripts" ) != "off" ) {
			$mainscript = "facebook_comment_slider.min.js";
		}
		else {
			$mainscript = "facebook_comment_slider.js";			
		}
			if (get_option('setting_applyhome')=='yes') $currentstyle = "home";
			wp_enqueue_style( 'facebook_comment_slider_style', plugins_url( '/templates/assets/css/facebook_comment_slider.css', __FILE__ ) );
			wp_enqueue_style( 'jquery_ui_style', plugins_url( '/templates/assets/css/jquery-ui.css', __FILE__ ) );
			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'jquery-ui-core', array( 'jquery' ) );
			wp_enqueue_script( 'jquery-effects-core', array( 'jquery' ) );
			wp_enqueue_script( 'jquery-effects-fade', array( 'jquery-effects-core' ) );
			wp_enqueue_script( 'jquery-effects-slide', array( 'jquery-effects-core' ) );
			wp_enqueue_script( 'jquery-effects-shake', array( 'jquery-effects-core' ) );
			wp_enqueue_script( 'jquerymousewheel', plugins_url( '/templates/assets/js/jquery.mousewheel.js', __FILE__ ), array( 'jquery' ), FB_COMMENT_SLIDER_VERSION, false );
			wp_enqueue_script( 'jscrollpane', plugins_url( '/templates/assets/js/jquery.jscrollpane.min.js', __FILE__ ), array( 'jquery' ), FB_COMMENT_SLIDER_VERSION, false );
			wp_register_script( 'facebook_comment_slider_script', plugins_url( '/templates/assets/js/' . $mainscript, __FILE__ ), array( 'jquery', 'jquery-ui-core', 'jquery-effects-core', 'jquery-effects-fade', 'jquery-effects-slide', 'jquery-effects-shake' ), FB_COMMENT_SLIDER_VERSION, false );
			wp_localize_script( 'facebook_comment_slider_script', 'fcs_params', array( 'direction1'=>$direction1, 'direction2'=>$direction2, 'direction3'=>$direction3, 'closeable'=>$closeable, 'timer'=>$timer, 'icontime'=>$icontime, 'transparency'=>$transparency, 'hide_icon'=>$hide_icon, 'icon_size1'=>$icon_size1, 'icon_size2'=>$icon_size2, 'icon_size3'=>$icon_size3, 'auto_open1'=>$auto_open1, 'auto_open2'=>$auto_open2, 'auto_open3'=>$auto_open3, 'lock_screen'=>$lock_screen, 'message'=>$message, 'likebox_message'=>$likebox_message, 'postbox_message'=>$postbox_message, 'dofsu'=>$dofsu, 'dom'=>$dom, 'doap'=>$doap, 'no_post_to_show'=>$no_post_to_show, 'appid'=>$appid, 'vertical_distance1'=>$vertical_distance1, 'vertical_distance2'=>$vertical_distance2, 'vertical_distance3'=>$vertical_distance3, 'home_page_style'=>$home_page_style, 'fbsitename'=>$fbsitename, 'currentstyle'=>$currentstyle, 'channel_url'=>$channel_url, 'local'=>$local, 'xid'=>$xid, 'scheme' => $scheme, 'skin' => $skin, 'hide_alreadyliked' => $hal, 'shake1' => $shake1, 'shake2' => $shake2, 'shake3' => $shake3, 'icon_url1' => $icon_url1, 'icon_url2' => $icon_url2, 'icon_url3' => $icon_url3, 'path' => admin_url( 'admin-ajax.php' ) ) );
			wp_enqueue_script( 'facebook_comment_slider_script' );
			$custom_css = get_option( 'setting_fbclcustomcss' );
			if ( $custom_css != ""  ) {
				wp_enqueue_style( 'facebook-comment-slider-custom-style', plugins_url( '/templates/assets/css/custom_fbcs.css', __FILE__ ) );
				wp_add_inline_style( 'facebook-comment-slider-custom-style', $custom_css );
			}		}
		/**
		* Add the settings link to the plugins page
		**/
		function plugin_settings_link($links)
		{ 
			$settings_link = '<a href="options-general.php?page=facebook_comment_slider">Settings</a>';
			array_unshift($links, $settings_link); 
			return $links; 
		}
		public function ajax_fbcs()
		{
			if (isset($_REQUEST['fbcscmd'])) $fbcscmd = $_REQUEST['fbcscmd'];
			if (isset($_REQUEST['message'])) $fbcsmessage = (array)json_decode(stripslashes($_REQUEST['message']));
			$nemail = get_option('setting_notification_email');
			if ($fbcscmd=="sendmail"&&!empty($nemail))
			{
				$body = "You've got a new comment on the following URL: ".$fbcsmessage['href']." 

Comment:

".$fbcsmessage['message']."

Moderate the comment: https://developers.facebook.com/tools/comments
";
				if (mail($nemail, 'NEW COMMENT', $body)) $result = true;
				else $result = false;
				if ($result==true) die("success");
				else die("error");
			}
			else die();
		}
	}
}
if(class_exists('facebook_comment_slider'))
{
	// call the main class
	$facebook_comment_slider = facebook_comment_slider::getInstance();
}
?>