<?php
/*
 * Plugin Name: Facebook Live Video Auto Embed
 * Plugin URI:  http://shispare.com/wordpress/facebook-live-video-auto-embed-wordpress-plugin/
 * Description: Automatically embed live videos of your facebook page (or any public facebook page) on your wordpress site whenever you go live on facebook. The plugin detects if the facebook page is currently live and embeds the live video automatically. Also has the ability to embed previously recorded live videos and uploaded videos of the Facebook page. Also has ability to configure a Site Wide Top Notification Bar to be displayed when your Facebook page goes live.
 * Version: 2.1
 * Author: Shispare
 * Author URI: http://www.shispare.com
 */
require_once 'inc/fb-sdk/autoload.php';
require_once 'inc/embedcodeslist.php';

add_action( 'admin_enqueue_scripts', 'fbjk_scripts' );
add_action( 'wp_enqueue_scripts', 'fbjk_publicscripts' );
add_action('admin_menu', 'fbjk_setup_menu');
add_action( 'fbjk_fbchecklive_cron_hook', 'fbjk_fbchecklive' );

register_activation_hook( __FILE__, 'fbjk_install' );
register_deactivation_hook( __FILE__, 'fbjk_deactivate' );
add_shortcode( 'fblivevideoembed', 'fblivevideoembed_handler' );
add_filter('cron_schedules','fbjk_add_cron_schedules');

/* This function loads admin section scripts and styles*/
function fbjk_scripts($hook) {
    global $settingspage, $embedcodepage, $addembedcodepage, $sitewidenotificationpage;
    if(($hook!=$settingspage) && ($hook!=$embedcodepage) && ($hook!=$addembedcodepage) && ($hook!=$sitewidenotificationpage))//making sure they do not load on other pages
      return;
    
    wp_enqueue_style( 'fbjk-style', plugins_url('css/style.css', __FILE__) );
    wp_enqueue_script( 'jquery' );
    wp_enqueue_script( 'fbjk-jscolor', plugins_url('js/jscolor.js', __FILE__) );
    wp_enqueue_script( 'fbjk-customjs', plugins_url('js/custom.js', __FILE__) );
}

/* This function loads public section scripts and styles*/
function fbjk_publicscripts() {   
    wp_enqueue_style( 'fbjk-style', plugins_url('css/style.css', __FILE__) );
    wp_enqueue_script( 'jquery' );
    if(get_option('fbjk-notificationstatus') && (get_option('fbjk-notificationstatus') == 'enabled')
       && get_option('fbjk-livestatus') && (get_option('fbjk-livestatus') == 'live'))
    {
      wp_enqueue_script( 'fbjk-notificationbar', plugins_url('js/notificationbar.js', __FILE__) );       
      $data = array( 
                    'msg' => get_option('fbjk-notificationmsg'),
                    'barbg' => get_option('fbjk-barbgcolor'),
                    'textcolor' => get_option('fbjk-msgtextcolor'),
                    'sticky' => get_option('fbjk-notificationsticky'),
                    'animated' => get_option('fbjk-notificationanimated'),
                    'link' => get_option('fbjk-notificationlink'),
                );
    	wp_localize_script( 'fbjk-notificationbar', 'fbjk_notificationbar_localize', $data );
    }
}

/* This function sets up admin section menu*/
function fbjk_setup_menu(){
        global $settingspage, $embedcodepage, $addembedcodepage, $sitewidenotificationpage;
        $settingspage = add_menu_page( 'Settings Facebook Live Video Auto Embed', 'FB Live Videos Auto Embed', 'manage_options', 'fbjk-livevideo-autoembed', 'fbjk_settings', 'dashicons-video-alt3' );
        add_submenu_page('fbjk-livevideo-autoembed', 'Settings Facebook Live Video Auto Embed', 'Settings', 'manage_options', 'fbjk-livevideo-autoembed', 'fbjk_settings');
        $embedcodepage = add_submenu_page('fbjk-livevideo-autoembed', 'Embed Codes List Facebook Live Video Auto Embed', 'Embed Codes List', 'manage_options', 'fbjk-livevideo-autoembed-embedcodes', 'fbjk_embedcodes');
        $addembedcodepage = add_submenu_page('fbjk-livevideo-autoembed', 'Embed Code Facebook Live Video Auto Embed', 'Create New Embed Code', 'manage_options', 'fbjk-livevideo-autoembed-embedcode-form', 'fbjk_embedcode_form');
        $sitewidenotificationpage = add_submenu_page('fbjk-livevideo-autoembed', 'Site Wide Notification Facebook Live Video Auto Embed', 'Site Wide Notification', 'manage_options', 'fbjk-livevideo-autoembed-sitewide-notification', 'fbjk_sitewide_notification');
}

/* This function displays settings page and handles settings form submission*/
function fbjk_settings(){
  echo '<div id="fbjk-settings" class="fbjk-page">';
  echo '<h1 class="h1fbjk">Settings - Facebook Live Video Auto Embed</h1>';
  $errors = '';
  echo '<div id="fbjk-fb-settings">';
  echo '<h2 class="h1fbjk">Facebook Settings</h2>';
  $msg = '<div class="update-nag notice"><p>Please enter App ID and App Secret of your facebook app. '
      . 'If you do not have a facebook app, <a target="_blank" href="http://shispare.com/wordpress/facebook-live-video-auto-embed-wordpress-plugin/#installation-guide">'
      . 'please follow the link</a> to create it in few easy steps.</p></div>';
  if(get_option('fbjk-appid') && get_option('fbjk-appsecret'))
  {
    $appid = get_option('fbjk-appid');
    $appsecret = get_option('fbjk-appsecret');
  }
  if(isset($_POST["submitted"]))
  {
    $appid = trim($_POST['appid']);
    $appsecret = trim($_POST['appsecret']);
    $errors = '';
    if(!isset($_POST['appid']) || empty($_POST['appid']))
    {
      $errors .= ' - Please enter App ID';
    }
    if(!isset($_POST['appsecret']) || empty($_POST['appsecret']))
    {
      $errors .= '<br /> - Please enter App Secret';
    }
  }
  if(empty($errors) && isset($appid) && isset($appsecret))
  {     
    $fb = new Facebook\Facebook([
        'app_id' => $appid,
        'app_secret' => $appsecret,
        'default_graph_version' => 'v2.7',
        ]);

    $request = $fb->request('GET', '/'.$appid.'?access_token='.$appid.'|'.$appsecret);

    try {
      $response = $fb->getClient()->sendRequest($request);
    } catch(Facebook\Exceptions\FacebookResponseException $e) {
      $errors .= '<br />Unable to connect using provided App ID and App Secret: ' . $e->getMessage();        
    } catch(Facebook\Exceptions\FacebookSDKException $e) {
      $errors .= '<br />Unable to connect using provided App ID and App Secret: ' . $e->getMessage();        
    }        
    
    if(empty($errors))
    {        
      update_option( 'fbjk-appid', $appid);
      update_option( 'fbjk-appsecret', $appsecret);
      $msg = '<div class="updated notice">You are connected to Facebook API using the following App ID and App Secret. You can <a href="'. admin_url('admin.php') .'?page=fbjk-livevideo-autoembed-embedcode-form">create Embed Codes</a> to embed live videos of any public facebook pages anywhere on your website.'
          . ' For assistance regarding usage of the plugin, please follow <a target="_blank" href="http://shispare.com/wordpress/facebook-live-video-auto-embed-wordpress-plugin/#user-guide">the user guide</a>.</div>';            
    }
  }
  if(!empty($errors))
  {
      $errors = '<div class="error notice">'.$errors.'</div>';        
  }
  echo $msg;
  echo $errors;
  echo '<form method="post" action="'
      . admin_url('admin.php') . '?page=fbjk-livevideo-autoembed';  
  echo '">'      
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">App ID:</div> '
      . '<div class="fbjk-right"><input type="text" name="appid" id="field_appid" value="'
      . (isset($appid)?$appid:'')
      . '"/></div><div class="clear"></div></div>'
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">App Secret:</div> '
      . '<div class="fbjk-right"><input type="password" name="appsecret" id="field_appsecret" value="'
      . (isset($appsecret)?$appsecret:'')
      . '"/></div><div class="clear"></div></div>'
      . '<input type="hidden" name="submitted" value="yes"/>'
      . '<div class="fbjk-fieldrow"><div class="fbjk-left"></div> '      
      . '<div class="fbjk-right"><button class="button button-primary" type="submit">Submit</button>'
      . '</div><div class="clear"></div></div>'
      . '</form></div></div>';

}

/* This function displays Site Wide notification settings page and handles form submission*/
function fbjk_sitewide_notification(){
  echo '<div id="fbjk_sitewide_notification" class="fbjk-form fbjk-page">';
  echo '<h1 class="h1fbjk">Site Wide Top Notification Bar - Facebook Live Video Auto Embed</h1>';
  $data = array();
  $errors = '';
  if(get_option('fbjk-appid') && get_option('fbjk-appsecret'))
  {
    $appid = get_option('fbjk-appid');
    $appsecret = get_option('fbjk-appsecret');
    $fb = new Facebook\Facebook([
          'app_id' => $appid,
          'app_secret' => $appsecret,
          'default_graph_version' => 'v2.7',
          ]);
  }
  else
  {
    echo '<div class="error notice">Sorry. You must enter your Facebook App ID and App Secret at <a href="'.admin_url('admin.php').'?page=fbjk-livevideo-autoembed">the settings page</a> before configuring Site Wide Notification Bar.</div>';
    return;
  }
  if(!isset($_POST["submitted"]))
  {
    if(get_option('fbjk-notificationpageusername') && get_option('fbjk-notificationmsg') && get_option('fbjk-barbgcolor') 
        && get_option('fbjk-msgtextcolor') && get_option('fbjk-notificationlink') && get_option('fbjk-notificationstatus')
        && get_option('fbjk-notificationsticky') && get_option('fbjk-notificationanimated'))
    {
      $data['notificationpageusername'] = get_option('fbjk-notificationpageusername');
      $data['notificationmsg'] = get_option('fbjk-notificationmsg');
      $data['barbgcolor'] = get_option('fbjk-barbgcolor');
      $data['msgtextcolor'] = get_option('fbjk-msgtextcolor');
      $data['notificationlink'] = get_option('fbjk-notificationlink');
      $data['notificationstatus'] = get_option('fbjk-notificationstatus');
      $data['notificationsticky'] = get_option('fbjk-notificationsticky');
      $data['notificationanimated'] = get_option('fbjk-notificationanimated');
      if($data['notificationstatus'] == 'enabled')
      {
        $msg = '<div class="updated notice">Site Wide Top Notification Bar is enabled for the Facebook page "'.$data['notificationpageusername']
              .'".</div>';
      }
      else
      {
        $msg = '<div class="update-nag notice">Site Wide Top Notification Bar is currently disabled</div>';
      }
      
    }
    else
    {
      $msg = '<div class="update-nag notice">Please enter the following information to enable Site Wide Top Notification Bar. '
           . 'This bar will display throughout your website whenever you are going live on your Facebook page.</div>';
    }
  }  
  else
  {
    $errors = '';      

    if(!isset($_POST['notificationpageusername']) || empty($_POST['notificationpageusername']))
    {
      $errors .= ' - Please enter Facebook Page Username';
    }
    else
    {      
      $data['notificationpageusername'] = trim($_POST['notificationpageusername']);
      $data['notificationpageusername'] = str_replace('@', '', $data['notificationpageusername']);
      $request = $fb->request('GET', '/'.$data['notificationpageusername'].'?access_token='.$appid.'|'.$appsecret);
      try {
        $response = $fb->getClient()->sendRequest($request);
      } catch(Facebook\Exceptions\FacebookResponseException $e) {
        // When Graph returns an error
        $errors .= '<br /> - Unable to get page data: ' . $e->getMessage();        
      } catch(Facebook\Exceptions\FacebookSDKException $e) {
        // When validation fails or other local issues
        $errors .= '<br /> - Unable to get page data: ' . $e->getMessage();        
      }  
    }
    if(!isset($_POST['notificationmsg']) || empty($_POST['notificationmsg']))
    {
      $errors .= '<br /> - Please enter notification message';
    }
    else
    {
      $data['notificationmsg'] = $_POST['notificationmsg'];      
    }
    if(!isset($_POST['barbgcolor']) || empty($_POST['barbgcolor']))
    {
      $errors .= '<br /> - Please select notification bar background color';
    }
    else
    {
      $data['barbgcolor'] = $_POST['barbgcolor'];      
    }
    if(!isset($_POST['msgtextcolor']) || empty($_POST['msgtextcolor']))
    {
      $errors .= '<br /> - Please select notification message text color';
    }
    else
    {
      $data['msgtextcolor'] = $_POST['msgtextcolor'];      
    } 
    if(!isset($_POST['notificationsticky']) || empty($_POST['notificationsticky']))
    {
      $errors .= '<br /> - Please select if the notification will be sticky or not';
    }
    else
    {
      $data['notificationsticky'] = $_POST['notificationsticky'];
    }  
    if(!isset($_POST['notificationanimated']) || empty($_POST['notificationanimated']))
    {
      $errors .= '<br /> - Please select if the notification should have blinking effect or not';
    }
    else
    {
      $data['notificationanimated'] = $_POST['notificationanimated'];
    }  
    if(!isset($_POST['notificationlink']) || empty($_POST['notificationlink']))
    {
      $errors .= '<br /> - Please enter the URL notification bar should link to';
    }
    else
    {
      $data['notificationlink'] = $_POST['notificationlink'];      
    } 
    if(!isset($_POST['notificationstatus']) || empty($_POST['notificationstatus']))
    {
      $errors .= '<br /> - Please select notification status';
    }
    else
    {
      $data['notificationstatus'] = $_POST['notificationstatus'];
    }   
    

    if(!empty($errors))
    {
      $data['notificationpageusername'] = stripslashes_deep($data['notificationpageusername']);
      $data['notificationmsg'] = stripslashes_deep($data['notificationmsg']);
      $data['barbgcolor'] = stripslashes_deep($data['barbgcolor']);
      $data['msgtextcolor'] = stripslashes_deep($data['msgtextcolor']);
      $data['notificationlink'] = stripslashes_deep($data['notificationlink']);
      echo '<div class="fbjk-errors">'.$errors.'</div>';        
    }
    else
    {         
      update_option( 'fbjk-notificationpageusername', $data['notificationpageusername']);
      update_option( 'fbjk-notificationmsg', $data['notificationmsg']);
      update_option( 'fbjk-barbgcolor', $data['barbgcolor']);
      update_option( 'fbjk-msgtextcolor', $data['msgtextcolor']);
      update_option( 'fbjk-notificationsticky', $data['notificationsticky']);
      update_option( 'fbjk-notificationanimated', $data['notificationanimated']);
      update_option( 'fbjk-notificationlink', $data['notificationlink']);
      update_option( 'fbjk-notificationstatus', $data['notificationstatus']);
      
      if($data['notificationstatus'] == 'enabled')
      {
        $msg = '<div class="updated notice">Site Wide Top Notification Bar is enabled for the Facebook page "'.$data['notificationpageusername']
              .'".</div>';
        if(!wp_next_scheduled( 'fbjk_fbchecklive_cron_hook' ))
        {          
          wp_schedule_event( time(), '10seconds', 'fbjk_fbchecklive_cron_hook' );
        }
      }
      else
      {
        $msg = '<div class="update-nag notice">Site Wide Top Notification Bar is currently disabled</div>';
        if(wp_next_scheduled( 'fbjk_fbchecklive_cron_hook' ))
        {
          wp_unschedule_event( wp_next_scheduled( 'fbjk_fbchecklive_cron_hook' ), 'fbjk_fbchecklive_cron_hook' );
        } 
      }
    }
  }

  $enabledselected = '';
  $disabledselected = '';

  if((isset($data['notificationsticky'])) && ($data['notificationsticky'] == 'yes'))
  {
      $stickyselected = ' selected="selected"';
  }
  elseif((isset($data['notificationsticky'])) && ($data['notificationsticky'] == 'no'))
  {
      $stickynotselected = ' selected="selected"';
  }
  if((isset($data['notificationanimated'])) && ($data['notificationanimated'] == 'yes'))
  {
      $animatedselected = ' selected="selected"';
  }
  elseif((isset($data['notificationanimated'])) && ($data['notificationanimated'] == 'no'))
  {
      $animatednotselected = ' selected="selected"';
  }
  if((isset($data['notificationstatus'])) && ($data['notificationstatus'] == 'enabled'))
  {
      $enabledselected = ' selected="selected"';
  }
  elseif((isset($data['notificationstatus'])) && ($data['notificationstatus'] == 'disabled'))
  {
      $disabledselected = ' selected="selected"';
  }
  if(isset($msg))
  {
    echo $msg;
  }
  echo '<form method="post" action="'
      . admin_url('admin.php') . '?page=fbjk-livevideo-autoembed-sitewide-notification">'
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">Facebook Page Username:<span class="fbjkreq">*</span></div> '
      . '<div class="fbjk-right"><input type="text" name="notificationpageusername" id="field_notificationpageusername" value="'
      . (isset($data['notificationpageusername'])?$data['notificationpageusername']:'')
      . '"/><br /> <span class="fbjk-hint">Enter Username of your Facebook page. '
      . '<a target="_blank" href="http://shispare.com/wordpress/facebook-live-video-auto-embed-wordpress-plugin/#user-guide">How to find Facebook Page Username?</a></span></div><div class="clear"></div></div>'
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">Notification Message:<span class="fbjkreq">*</span></div> '
      . '<div class="fbjk-right"><textarea name="notificationmsg" id="field_notificationmsg" cols="44" rows="6">'
      . (isset($data['notificationmsg'])?$data['notificationmsg']:'')
      . '</textarea><br />'
      . '<span class="fbjk-hint">Text to be displayed in the notification bar when the Facebook page is currently live.</span>'      
      . '</div><div class="clear"></div></div>'
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">Notification Bar Background Color<span class="fbjkreq">*</span></div> '
      . '<div class="fbjk-right"><input type="text" name="barbgcolor" id="field_barbgcolor" class="fbjkjscolor" value="'
      . (isset($data['barbgcolor'])?$data['barbgcolor']:'000000')
      . '"/><br />'
      . '<span class="fbjk-hint">Background color of the Top Notification Bar.</span>'        
      . '</div><div class="clear"></div></div>' 
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">Notification Text Color<span class="fbjkreq">*</span></div> '
      . '<div class="fbjk-right"><input type="text" name="msgtextcolor" id="field_msgtextcolor" class="fbjkjscolor" value="'
      . (isset($data['msgtextcolor'])?$data['msgtextcolor']:'FFFFFF')
      . '"/><br />'
      . '<span class="fbjk-hint">Text color of the Top Notification Bar.</span>'        
      . '</div><div class="clear"></div></div>'
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">Sticky:<span class="fbjkreq">*</span></div> '       
      . '<div class="fbjk-right"><select name="notificationsticky" id="field_notificationsticky">'    
      . '<option value="">--- SELECT ---</option>'
      . '<option value="yes"'.$stickyselected.'>Yes</option>'
      . '<option value="no"'.$stickynotselected.'>No</option>'
      . '</select><br />'
      . '<span class="fbjk-hint">Select if the notification bar should stick to the top when user scrolls the page.</span>' 
      . '</div><div class="clear"></div></div>'
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">Blinking Effect:<span class="fbjkreq">*</span></div> '       
      . '<div class="fbjk-right"><select name="notificationanimated" id="field_notificationanimated">'    
      . '<option value="">--- SELECT ---</option>'
      . '<option value="yes"'.$animatedselected.'>Yes</option>'
      . '<option value="no"'.$animatednotselected.'>No</option>'
      . '</select><br />'
      . '<span class="fbjk-hint">Select if the notification bar should have a blinking effect.</span>' 
      . '</div><div class="clear"></div></div>'
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">Notification Link<span class="fbjkreq">*</span></div> '
      . '<div class="fbjk-right"><input type="text" name="notificationlink" id="field_notificationlink" value="'
      . (isset($data['notificationlink'])?$data['notificationlink']:'')
      . '"/><br />'
      . '<span class="fbjk-hint">The URL to which the notification bar should be linked. Usually this should be the URL of the page/post you have put your Embed Code on.</span>'        
      . '</div><div class="clear"></div></div>' 
      . '<div class="fbjk-fieldrow"><div class="fbjk-left">Status:<span class="fbjkreq">*</span></div> '       
      . '<div class="fbjk-right"><select name="notificationstatus" id="field_notificationstatus">'    
      . '<option value="">--- SELECT ---</option>'
      . '<option value="enabled"'.$enabledselected.'>Enabled</option>'
      . '<option value="disabled"'.$disabledselected.'>Disabled</option>'
      . '</select><br />'
      . '<span class="fbjk-hint">Enable/ Disable the Top Notification Bar.</span>'        
      . '</div><div class="clear"></div></div>'            
      . '<input type="hidden" name="submitted" value="yes"/>'
      . '<div class="fbjk-fieldrow"><div class="fbjk-left"></div> '
      . '<div class="fbjk-right"><button id="submit_notification_form" class="button button-primary" type="submit">Submit</button></div>'
      . '<div class="clear"></div></div></form>';
  echo '</div>';
}

/* This function takes a single configuration record as input and returns array of facebook videos*/
function loadvideos($fbjkconfig)
{
  if(get_option('fbjk-appid') && get_option('fbjk-appsecret'))
  {
    $appid = get_option('fbjk-appid');
    $appsecret = get_option('fbjk-appsecret');
    $fb = new Facebook\Facebook([
          'app_id' => $appid,
          'app_secret' => $appsecret,
          'default_graph_version' => 'v2.7',
          ]);
  }
  else
  {
    return 'Unable to load video. Facebook App ID and/or App Secret missing.';
  }
  $videos = array();
  if(!isset($fbjkconfig->maxrecorded) || is_null($fbjkconfig->maxrecorded) || empty($fbjkconfig->maxrecorded))
    $fbjkconfig->maxrecorded = 1;  
  
  $request = $fb->request('GET', '/'.$fbjkconfig->pageusername.'/videos?fields=live_status,permalink_url,description,embeddable&access_token='.$appid.'|'.$appsecret);

  try {
    $response = $fb->getClient()->sendRequest($request);
  } catch(Facebook\Exceptions\FacebookResponseException $e) {
    return 'Error loading: ' . $e->getMessage();
  } catch(Facebook\Exceptions\FacebookSDKException $e) {
    return 'Error loading: ' . $e->getMessage();
  }
  //echo var_dump($response);
 // $graphNode = $response->getGraphNode();
  $graphEdge = $response->getGraphEdge();   
  if($fbjkconfig->videotype == "live")
  {
    if(!is_null($graphEdge) && !empty($graphEdge))
    {
      foreach($graphEdge as $gnode)
      {       
        if(isset($gnode['live_status']))
        {
          if(strtolower($gnode['live_status']) == 'live')
          {
            $video = array();
            $video['id'] = $gnode['id'];
            $video['permalink_url'] = $gnode['permalink_url'];
            if(isset($gnode['description']))
            $video['description'] = $gnode['description'];
            $videos[] = $video;
          }
        }
      }
    }
  }
  else
  {
    while(count($videos) < $fbjkconfig->maxrecorded)
    {
      if(!is_null($graphEdge) && !empty($graphEdge))
      {
        foreach($graphEdge as $gnode)
        { 
          if(!$gnode['embeddable']) // if not an embeddable video skip it
            continue;
          
          if(isset($gnode['live_status']))
          {
            if($fbjkconfig->videotype == "recorded")
            {
              if(strtolower($gnode['live_status']) == 'vod')
              {
                if( count($videos) < $fbjkconfig->maxrecorded )
                {
                  $video = array();
                  $video['id'] = $gnode['id'];
                  $video['permalink_url'] = $gnode['permalink_url'];
                  if(isset($gnode['description']))
                  $video['description'] = $gnode['description'];
                  $videos[] = $video;
                }
                else
                {
                  break 2;
                }
              }
            }
          }
          else
          {
            if($fbjkconfig->videotype == "uploaded")
            {
              if( count($videos) < $fbjkconfig->maxrecorded )
              {
                $video = array();
                $video['id'] = $gnode['id'];
                $video['permalink_url'] = $gnode['permalink_url'];
                if(isset($gnode['description']))
                $video['description'] = $gnode['description'];
                $videos[] = $video;    
              }
              else
              {
                break 2;
              }
            }
          }    
        }
        $graphEdge = $fb->next($graphEdge);
      }
      else
      {
        break;
      }
    }
  }
  return $videos;
}

/* This function handles fblivevideoembed shortcode. Gets configuration record by ID and returns HTML containing embedded videos*/
function fblivevideoembed_handler( $atts ) {
    static $firstexec = true;
    static $livenow = false;
    $a = shortcode_atts( array(
        'id' => '0'
    ), $atts );

    if($a['id'])
    {
      global $wpdb;
      $table_name = $wpdb->prefix . "fbjkembedcodes";
      $result = $wpdb->get_results ( "SELECT * FROM ".$table_name." where id='".$a['id']."'");
      if(!count($result))
      {
        return "The shortcode ID used here no longer exists.";
      }
      foreach($result as $row)
      {
        $fbjkconfig = $row;
      } 
      if((($fbjkconfig->videotype == "recorded") || ($fbjkconfig->videotype == "uploaded")) 
          && !is_null($fbjkconfig->hideiflive) && $fbjkconfig->hideiflive && $livenow)
      {
        return '';
      }
      if($fbjkconfig->usecache && (($fbjkconfig->videotype == "recorded") || ($fbjkconfig->videotype == "uploaded"))
         && !is_null($fbjkconfig->lastrequestresult) && !empty($fbjkconfig->lastrequestresult))
      {
        $currenttime = time();
        $cachetime = $fbjkconfig->lastrequest;
        $cacherefreshtime = $fbjkconfig->cacherefreshtime*60;
        
      }
      if(isset($currenttime) && (($currenttime - $cachetime) < $cacherefreshtime))
      {
        $videos = json_decode($fbjkconfig->lastrequestresult, true);
        $loadedfromcache = true;
      }
      else
      {
        $loadedfromcache = false;
        $response = loadvideos($fbjkconfig);
        if(is_array($response))
          $videos = $response;
        else
          return $response;
      }
      
      if(!count($videos))
      {
        if( $fbjkconfig->alternatebehaviour == "showmsg" )
        {
          if($fbjkconfig->videotype == "live")
          {
            global $wp;
            $current_url = add_query_arg( $wp->query_string, '', home_url( $wp->request ) );
            return '<p class="fbjkmsg">'.$fbjkconfig->alternatemsg.'</p>'.'<div class="fbjkrefresh"><a href="'.$current_url.'">Refresh</a></div>';
          }
          else
          {
            return '<p class="fbjkmsg">'.$fbjkconfig->alternatemsg.'</p>';
          }
        }
        else
        {
          return "";
        }
      }
      else
      {
        if($fbjkconfig->videotype == "live")
        {
          $livenow = true;
        }
        if($fbjkconfig->usecache && !$loadedfromcache)
        { 
          $where = array();
          $where['id'] = $fbjkconfig->id;
          $update = array();
          $update['lastrequest'] = time();
          $update['lastrequestresult'] = json_encode($videos);
          $updated = $wpdb->update($table_name, $update, $where);
        }
      }
        
      ob_start();
      if(isset($fbjkconfig->msg) && !empty($fbjkconfig->msg))
      {
        echo '<p class="fbjkmsg">'.stripslashes_deep($fbjkconfig->msg).'</p>';        
      }
      if($firstexec)
      {
      ?>
      <div id="fb-root"></div>
      <script>
        (function(d, s, id) {
          var js, fjs = d.getElementsByTagName(s)[0];
          if (d.getElementById(id)) return;
          js = d.createElement(s); js.id = id;
          js.src = "//connect.facebook.net/en_US/sdk.js#xfbml=1&version=v2.7&appId=<?php echo $appid;?>";
          fjs.parentNode.insertBefore(js, fjs);
        }(document, 'script', 'facebook-jssdk'));        

      var removebg = window.setInterval(function(){               
        var counter = 0;        
        jQuery(".fb-video iframe").each(function(i, obj){
          if(jQuery(this).css("visibility") == "visible")
          {
            jQuery(this).parent().parent().css("background-image","none");
            counter++;
          }
        });
        if(counter == jQuery(".fb-video iframe").length)
          clearInterval(removebg);
      }, 3000);

      
      </script>  
      
      <?php    
       $firstexec = false;
      }
      foreach($videos as $video)
      {
      ?>  
        <div class="fb-video" data-href="https://www.facebook.com<?php echo $video['permalink_url'];?>" 
             data-width="<?php echo $fbjkconfig->width;?>" data-show-text="<?php echo ($fbjkconfig->showdesc)?'true':'false';?>" 
             data-allowfullscreen="<?php echo ($fbjkconfig->allowfullscreen)?'true':'false';?>">
          <blockquote cite="https://www.facebook.com<?php echo $video['permalink_url'];?>" class="fb-xfbml-parse-ignore">
            <a href="https://www.facebook.com<?php echo $video['permalink_url'];?>"><?php echo isset($video['description'])?$video['description']:'Video';?></a>            
          </blockquote>
        </div>      
      <?php 
      }
      ?>
      <?php
      return ob_get_clean();
    }
    else
    {
      return "Please enter embed code ID";
    }
}

/*Get refresh button for admin section*/
function fbjk_RefreshAdminButton($text = 'Refresh')
{
  return '<div class="fbjkrefresh"><a href="'.admin_url( "admin.php?page=".$_GET["page"] ).'">'.$text.'</a></div>';
}

/* This function displays Embed Codes list page*/
function fbjk_embedcodes(){
    global $wpdb;
    $table_name = $wpdb->prefix . "fbjkembedcodes";
    if(isset($_GET['embedcodeid']) && !empty($_GET['embedcodeid']) && isset($_GET['delete']))//if delete request
    {
      $wpdb->delete($table_name, array('id'=>addslashes($_GET['embedcodeid'])));
      echo '<div class="updated notice"><p>Embed Code deleted successfully</p></div>'.fbjk_RefreshAdminButton("Back");
      return;
    }
    echo '<div class="fbjk-main fbjk-page">';
    echo '<h1 class="h1fbjk">Embed Codes List - Facebook Live Video Auto Embed</h1><p>List of embed codes.</p>';
   
    $fbjkembedcodesListTable = new fbjkembedcodes_List_Table();
    $fbjkembedcodesListTable->prepare_items(); 
    $fbjkembedcodesListTable->display(); 
    echo '<a class="fbjkcreatenew" href="'.admin_url('admin.php') . '?page=fbjk-livevideo-autoembed-embedcode-form">Create New Embed Code</a>';
    echo '</div>';
}

/* This function takes $data and either creates a new record in wp_fbjkembedcodes table or updates an existing one*/
function fbjk_submittodb($data){
  global $wpdb;
  $table_name = $wpdb->prefix . "fbjkembedcodes"; 
  
  if($data['showdesc'] == 'yes')
    $data['showdesc'] = 1;
  else 
    $data['showdesc'] = 0;
  
  if(isset($data['allowfullscreen']) && ($data['allowfullscreen'] == 'yes'))
    $data['allowfullscreen'] = 1;
  else 
    $data['allowfullscreen'] = 0;
  
  if(isset($data['usecache']) && ($data['usecache'] == 'yes'))
    $data['usecache'] = 1;
  else 
    $data['usecache'] = 0;
  
  if(isset($data['hideiflive']) && ($data['hideiflive'] == 'yes'))
    $data['hideiflive'] = 1;
  else 
    $data['hideiflive'] = 0;
  
  $msg= "";
  if(isset($_GET['embedcodeid']))
  {
    $where = array();
    $where['id'] = $_GET['embedcodeid'];
    $updated = $wpdb->update($table_name, $data, $where);
    if ( false === $updated ) {
        // There was an error.
      $msg = '<div class="error notice">There was an error updating the embedcode configuration.<br />'.$wpdb->last_error.'</div>'.fbjk_RefreshAdminButton("Back");
    } else {
        // No error. You can check updated to see how many rows were changed.
      $msg = '<div class="updated notice">Embed Code configuration updated successfully</div>'.fbjk_RefreshAdminButton("Back");
    }
  }
  else
  {
    $inserted = $wpdb->insert($table_name, $data);
    if(!$inserted)
    {
      $msg = '<div class="error notice">There was an error creating new Embed Code.<br />'.$wpdb->last_error.'</div>'.fbjk_RefreshAdminButton("Back");
    }
    else
    {
      $msg = '<div class="updated notice">New Embed Code created successfully</div>'.fbjk_RefreshAdminButton("Back");
    }
  }
  return $msg;
  
}

/* This function displays add/edit Embed code form and handles form submission*/
function fbjk_embedcode_form(){
    global $wpdb;   
    $table_name = $wpdb->prefix . "fbjkembedcodes";
    $data = array();
    if(get_option('fbjk-appid') && get_option('fbjk-appsecret'))
    {
      $appid = get_option('fbjk-appid');
      $appsecret = get_option('fbjk-appsecret');
      $fb = new Facebook\Facebook([
            'app_id' => $appid,
            'app_secret' => $appsecret,
            'default_graph_version' => 'v2.7',
            ]);
    }
    else
    {
      echo '<div class="error notice">Sorry. You must enter your Facebook App ID and App Secret at <a href="'.admin_url('admin.php').'?page=fbjk-livevideo-autoembed">the settings page</a> before configuring Embed Codes.</div>';
      return;
    }
    

    
    echo '<div class="fbjk-form fbjk-page">';
    if(isset($_GET['embedcodeid']) && !empty($_GET['embedcodeid']))//if edit request
    {
      if(!isset($_POST["submitted"]))
      {        
        $result = $wpdb->get_results ( "SELECT * FROM ".$table_name." where id='".$_GET['embedcodeid']."'", 'ARRAY_A');
        foreach($result as $row)
        {
          $data = $row;
        }
        
        if($data['showdesc'])
        {
          $data['showdesc'] = 'yes';
        }
        else
        {
          $data['showdesc'] = 'no';
        }
                
        if(!is_null($data['allowfullscreen']))
        {
          if($data['allowfullscreen'])
          {
            $data['allowfullscreen'] = 'yes';
          }
          else
          {
            $data['allowfullscreen'] = 'no';
          }
        }
        else
        {
          unset($data['allowfullscreen']);
        }
        
        if(!is_null($data['usecache']))
        {
          if($data['usecache'])
          {
            $data['usecache'] = 'yes';
          }
          else
          {
            $data['usecache'] = 'no';
          }
        }
        else
        {
          unset($data['usecache']);
        }
        
        if(!is_null($data['hideiflive']))
        {
          if($data['hideiflive'])
          {
            $data['hideiflive'] = 'yes';
          }
          else
          {
            $data['hideiflive'] = 'no';
          }
        }
        else
        {
          unset($data['hideiflive']);
        }
      }
      echo '<h1 class="h1fbjk">Edit Embed Code - Facebook Live Video Auto Embed</h1><p>Edit configuration of Embed Code.</p>';
    }
    else
    {
      echo '<h1 class="h1fbjk">Create New Embed Code - Facebook Live Video Auto Embed</h1><p>Configure a new Embed Code to automatically embed live videos of your facebook page or any public facebook page.</p>';
    }
    if(isset($_POST["submitted"]))
    {
      $errors = '';      
        
      if(!isset($_POST['pageusername']) || empty($_POST['pageusername']))
      {
        $errors .= ' - Please enter Facebook Page Username';
      }
      else
      {      
        $data['pageusername'] = trim($_POST['pageusername']);
        $data['pageusername'] = str_replace('@', '', $data['pageusername']);
        $request = $fb->request('GET', '/'.$data['pageusername'].'?access_token='.$appid.'|'.$appsecret);
        try {
          $response = $fb->getClient()->sendRequest($request);
        } catch(Facebook\Exceptions\FacebookResponseException $e) {
          // When Graph returns an error
          $errors .= '<br /> - Unable to get page data: ' . $e->getMessage();        
        } catch(Facebook\Exceptions\FacebookSDKException $e) {
          // When validation fails or other local issues
          $errors .= '<br /> - Unable to get page data: ' . $e->getMessage();        
        }  
      }
      if(!isset($_POST['videotype']) || empty($_POST['videotype']))
      {
        $errors .= '<br /> - Please select a Video Type';
      }
      else
      {
        $data['videotype'] = $_POST['videotype'];
        if(($data['videotype'] == "recorded") || ($data['videotype'] == "uploaded"))
        {          
          if(!isset($_POST['maxrecorded']) || empty($_POST['maxrecorded']))
          {
            $errors .= '<br /> - Please enter Maximum Videos';            
          }
          else
          {
            $data['maxrecorded'] = $_POST['maxrecorded'];
          }   
          if(!isset($_POST['usecache']) || empty($_POST['usecache']))
          {
            $errors .= '<br /> - Please select whether to use cache or not';            
          }
          else
          {            
            $data['usecache'] = $_POST["usecache"];
            if($data['usecache'] == "yes")
            {            
              if(!isset($_POST['cacherefreshtime']) || empty($_POST['cacherefreshtime']))
              {
                $errors .= '<br /> - Please enter Cache Refresh Time';
              }
              else
              {
                $data['cacherefreshtime'] = $_POST['cacherefreshtime'];
              } 
            }
          }   
          if(!isset($_POST['hideiflive']) || empty($_POST['hideiflive']))
          {
            $errors .= '<br /> - Please select yes or no in the Hide if Live option';            
          }
          else
          {            
            $data['hideiflive'] = $_POST["hideiflive"];
          } 
          $data['allowfullscreen'] = $_POST['allowfullscreen'];
        }
      }      
      if(!isset($_POST['width']) || empty($_POST['width']))
      {
        $errors .= '<br /> - Please enter Width of player';
      }
      else
      {
        $data['width'] = $_POST['width'];
      }   
      if(!isset($_POST['alternatebehaviour']) || empty($_POST['alternatebehaviour']))
      {
        $errors .= '<br /> - Please select an Alternate Behaviour';
      }
      else
      {
        $data['alternatebehaviour'] = $_POST['alternatebehaviour'];
        if($data['alternatebehaviour'] == "showmsg")
        {
          if(!isset($_POST['alternatemsg']) || empty($_POST['alternatemsg']))
          {
            $errors .= '<br /> - Please enter Alternate Message';
          }
          else
          {
            $data['alternatemsg'] = $_POST['alternatemsg'];
          }          
        }
      }
      $data['msg'] = $_POST['msg']; 
      $data['showdesc'] = $_POST['showdesc']; 
      
      if(!empty($errors))
      {
        $data['pageusername'] = stripslashes_deep($data['pageusername']);
        $data['alternatemsg'] = stripslashes_deep($data['alternatemsg']);
        $data['msg'] = stripslashes_deep($data['msg']);
        echo '<div class="fbjk-errors">'.$errors.'</div>';        
      }
      else
      {         
        $successmsg = fbjk_submittodb($data); 
        echo $successmsg;
        return;        
      }
    }
      
    $liveselected = '';
    $recordedselected = '';
    $uploadedselected = '';
    $showmsgselected = '';
    $shownothingselected = '';
    $showdescyesselected = '';
    $showdescnoselected = '';
    $allowfullscreenyesselected = '';
    $allowfullscreennoselected = '';
    $usecacheyesselected = '';
    $usecachenoselected = '';
    $hideifliveyesselected = '';
    $hideiflivenoselected = '';
    
    $maxrecordedhidden = 'fbjk-hidden';
    $allowfullscreenhidden = 'fbjk-hidden';
    $alternatemsghidden = 'fbjk-hidden';
    $usecachehidden = 'fbjk-hidden';
    $hideiflivehidden = 'fbjk-hidden';
    $cacherefreshtimehidden = 'fbjk-hidden';
    $msghintlivehidden = 'fbjk-hidden';
    $msghintrecordedhidden = 'fbjk-hidden';
    $msghintuploadedhidden = 'fbjk-hidden';
    $alternatehintlivehidden = 'fbjk-hidden';
    $alternatehintrecordedhidden = 'fbjk-hidden';
    $alternatehintuploadedhidden = 'fbjk-hidden';
    $alternatemsghintlivehidden = 'fbjk-hidden';
    $alternatemsghintrecordedhidden = 'fbjk-hidden';
    $alternatemsghintuploadedhidden = 'fbjk-hidden';
    
    if((isset($data['videotype'])) && ($data['videotype'] == 'live'))
    {
        $liveselected = ' selected="selected"';
        $msghintlivehidden = '';
        $alternatehintlivehidden = '';
        $alternatemsghintlivehidden = '';
    }
    elseif((isset($data['videotype'])) && ($data['videotype'] == 'recorded'))
    {
        $recordedselected = ' selected="selected"';
        $usecachehidden = '';
        $hideiflivehidden = '';
        $maxrecordedhidden = '';
        $msghintrecordedhidden = '';
        $alternatehintrecordedhidden = '';
        $alternatemsghintrecordedhidden = '';
        $allowfullscreenhidden = '';
    }
    elseif((isset($data['videotype'])) && ($data['videotype'] == 'uploaded'))
    {
        $uploadedselected = ' selected="selected"';
        $usecachehidden = '';
        $hideiflivehidden = '';
        $maxrecordedhidden = '';
        $msghintuploadedhidden = '';
        $alternatehintuploadedhidden = '';
        $alternatemsghintuploadedhidden = '';
        $allowfullscreenhidden = '';
    } 
    if((isset($data['alternatebehaviour'])) && ($data['alternatebehaviour'] == 'showmsg'))
    {
        $showmsgselected = ' selected="selected"';
        $alternatemsghidden = '';
    }
    elseif((isset($data['alternatebehaviour'])) && ($data['alternatebehaviour'] == 'shownothing'))
    {
        $shownothingselected = ' selected="selected"';
    }
    if((isset($data['showdesc'])) && ($data['showdesc'] == 'yes'))
    {
        $showdescyesselected = ' selected="selected"';
    }
    elseif((isset($data['showdesc'])) && ($data['showdesc'] == 'no'))
    {
        $showdescnoselected = ' selected="selected"';
    }      
    if((isset($data['allowfullscreen'])) && ($data['allowfullscreen'] == 'yes'))
    {
        $allowfullscreenyesselected = ' selected="selected"';
    }
    elseif((isset($data['allowfullscreen'])) && ($data['allowfullscreen'] == 'no'))
    {
        $allowfullscreennoselected = ' selected="selected"';
    } 
    if((isset($data['usecache'])) && ($data['usecache'] == 'yes'))
    {
        $usecacheyesselected = ' selected="selected"';
        $cacherefreshtimehidden = '';
    }
    elseif((isset($data['usecache'])) && ($data['usecache'] == 'no'))
    {
        $usecachenoselected = ' selected="selected"';
    } 
    if((isset($data['hideiflive'])) && ($data['hideiflive'] == 'yes'))
    {
        $hideifliveyesselected = ' selected="selected"';
    }
    elseif((isset($data['hideiflive'])) && ($data['hideiflive'] == 'no'))
    {
        $hideiflivenoselected = ' selected="selected"';
    } 
   
      
    
    echo '<form method="post" action="'
        . admin_url('admin.php') . '?page=fbjk-livevideo-autoembed-embedcode-form';
    echo (isset($_GET['embedcodeid']) && !empty($_GET['embedcodeid']))?'&embedcodeid='.$_GET['embedcodeid']:'';
    echo '">'
        . '<div class="fbjk-fieldrow"><div class="fbjk-left">Facebook Page Username:<span class="fbjkreq">*</span></div> '
        . '<div class="fbjk-right"><input type="text" name="pageusername" id="field_pageusername" value="'
        . (isset($data['pageusername'])?$data['pageusername']:'')
        . '"/><br /> <span class="fbjk-hint">Enter Username of facebook page whose Live video(s) you want to embed. '
        . '<a target="_blank" href="http://shispare.com/wordpress/facebook-live-video-auto-embed-wordpress-plugin/#user-guide">How to find Facebook Page Username?</a></span></div><div class="clear"></div></div>'
        . '<div class="fbjk-fieldrow"><div class="fbjk-left">Video Type:<span class="fbjkreq">*</span></div> '       
        . '<div class="fbjk-right"><select name="videotype" id="field_videotype">'    
        . '<option value="">--- SELECT ---</option>'
        . '<option value="live"'.$liveselected.'>Currently Live Video</option>'
        . '<option value="recorded"'.$recordedselected.'>Recent Live Videos (Recorded)</option>'
        . '<option value="uploaded"'.$uploadedselected.'>Recent Uploaded Videos</option>'
        . '</select></div><div class="clear"></div></div>'
        . '<div class="fbjk-fieldrow forrecordedanduploaded '.$maxrecordedhidden.'"><div class="fbjk-left subfield">Maximum Videos:<span class="fbjkreq">*</span></div> '
        . '<div class="fbjk-right subfield"><input type="text" name="maxrecorded" id="field_maxrecorded" value="'
        . (isset($data['maxrecorded'])?$data['maxrecorded']:'3')
        . '"/><br /><span class="fbjk-hint">Maximum number of videos to be embedded.</span>'
        . '</div><div class="clear"></div></div>' 
        . '<div class="fbjk-fieldrow"><div class="fbjk-left">Video Player(s) Width:<span class="fbjkreq">*</span></div> '
        . '<div class="fbjk-right"><input type="text" name="width" id="field_width" value="'
        . (isset($data['width'])?$data['width']:'500')
        . '"/><br /><span class="fbjk-hint">Video Player(s) width in pixels.</span></div><div class="clear"></div></div>'        
        . '<div class="fbjk-fieldrow"><div class="fbjk-left">Top Message:</div> '
        . '<div class="fbjk-right"><textarea name="msg" id="field_msg" cols="44" rows="6">'
        . (isset($data['msg'])?$data['msg']:'')
        . '</textarea><br />'
        . '<span class="fbjk-hint forlive '.$msghintlivehidden.'">Custom message to be displayed above live video embed when the page is going live. Leave empty for none.</span>'
        . '<span class="fbjk-hint forrecorded '.$msghintrecordedhidden.'">Custom message to be displayed above recorded live videos embeds. Leave empty for none.</span>'
        . '<span class="fbjk-hint foruploaded '.$msghintuploadedhidden.'">Custom message to be displayed above uploaded videos embeds. Leave empty for none.</span>'
        . '</div><div class="clear"></div></div>'
        . '<div class="fbjk-fieldrow"><div class="fbjk-left">Alternate Behaviour:<span class="fbjkreq">*</span></div> '       
        . '<div class="fbjk-right"><select name="alternatebehaviour" id="field_alternatebehaviour">'    
        . '<option value="">--- SELECT ---</option>'
        . '<option value="showmsg"'.$showmsgselected.'>Show Custom Message</option>'
        . '<option value="shownothing"'.$shownothingselected.'>Show Nothing</option>'
        . '</select><br />'
        . '<span class="fbjk-hint forlive '.$alternatehintlivehidden.'">Please select how the plugin should behave if the page is not currently live.</span>'
        . '<span class="fbjk-hint forrecorded '.$alternatehintrecordedhidden.'">Please select how the plugin should behave if there is no recently recorded live video of the page.</span>'
        . '<span class="fbjk-hint foruploaded '.$alternatehintuploadedhidden.'">Please select how the plugin should behave if there is no recently uploaded video of the page.</span>'
        . '</div><div class="clear"></div></div>' 
        . '<div class="fbjk-fieldrow '.$alternatemsghidden.'"><div class="fbjk-left subfield">Alternate Message:<span class="fbjkreq">*</span></div> '
        . '<div class="fbjk-right subfield"><textarea name="alternatemsg" id="field_alternatemsg" cols="37" rows="6">'
        . (isset($data['alternatemsg'])?$data['alternatemsg']:'')
        . '</textarea><br />'
        . '<span class="fbjk-hint forlive '.$alternatemsghintlivehidden.'">Custom message to be displayed if the page is not live at the moment.</span>'
        . '<span class="fbjk-hint forrecorded '.$alternatemsghintrecordedhidden.'">Custom message to be displayed if there is no recently recorded live video of the page.</span>'
        . '<span class="fbjk-hint foruploaded '.$alternatemsghintuploadedhidden.'">Custom message to be displayed if there is no recently uploaded video of the page.</span>'
        . '</div><div class="clear"></div></div>'  
        . '<div class="fbjk-fieldrow"><div class="fbjk-left">Show Full Post:<span class="fbjkreq">*</span></div> '       
        . '<div class="fbjk-right"><select name="showdesc" id="field_showdesc">'    
        . '<option value="yes"'.$showdescyesselected.'>Yes</option>'
        . '<option value="no"'.$showdescnoselected.'>No</option>'
        . '</select>' 
        . '<span class="fbjk-hint">Select whether to show video description and like/comment/share buttons in the video player or not. (Description which is usually entered at the time of going live on facebook.)</span>' 
        . '</div><div class="clear"></div></div>'         
        . '<div class="fbjk-fieldrow forrecordedanduploaded '.$allowfullscreenhidden.'"><div class="fbjk-left">Allow Full Screen:<span class="fbjkreq">*</span></div> '       
        . '<div class="fbjk-right"><select name="allowfullscreen" id="field_allowfullscreen">'    
        . '<option value="yes"'.$allowfullscreenyesselected.'>Yes</option>'
        . '<option value="no"'.$allowfullscreennoselected.'>No</option>'
        . '</select>'         
        . '</div><div class="clear"></div></div>' 
        . '<div class="fbjk-fieldrow forrecordedanduploaded '.$usecachehidden.'"><div class="fbjk-left">Use Cache:<span class="fbjkreq">*</span></div> '       
        . '<div class="fbjk-right"><select name="usecache" id="field_usecache">' 
        . '<option value="">--- SELECT ---</option>'
        . '<option value="yes"'.$usecacheyesselected.'>Yes</option>'
        . '<option value="no"'.$usecachenoselected.'>No</option>'
        . '</select><br />'        
        . '<span class="fbjk-hint">Recommended for recorded live videos and uploaded videos. Especially for pages with large number of videos and followers.</span>'
        . '</div><div class="clear"></div></div>' 
        . '<div class="fbjk-fieldrow '.$cacherefreshtimehidden.'"><div class="fbjk-left subfield">Cache Refresh Time:<span class="fbjkreq">*</span></div> '
        . '<div class="fbjk-right subfield"><input type="text" name="cacherefreshtime" id="field_cacherefreshtime" value="'
        . (isset($data['cacherefreshtime'])?$data['cacherefreshtime']:'15')
        . '"/><br />'
        . '<span class="fbjk-hint">Cache refresh time in minutes. Leave as is if unsure.</span>'        
        . '</div><div class="clear"></div></div>'        
        . '<div class="fbjk-fieldrow forrecordedanduploaded '.$hideiflivehidden.'"><div class="fbjk-left">Hide if Live:<span class="fbjkreq">*</span></div> '       
        . '<div class="fbjk-right"><select name="hideiflive" id="field_hideiflive">' 
        . '<option value="">--- SELECT ---</option>'
        . '<option value="yes"'.$hideifliveyesselected.'>Yes</option>'
        . '<option value="no"'.$hideiflivenoselected.'>No</option>'
        . '</select><br />'        
        . '<span class="fbjk-hint">If this option is selected the plugin will not display anything from this embed code if there is already a live video on the website page.</span>'
        . '</div><div class="clear"></div></div>'
        . '<input type="hidden" name="submitted" value="yes"/>'
        . '<div class="fbjk-fieldrow"><div class="fbjk-left"></div> '
        . '<div class="fbjk-right"><button id="submit_embedcode_form" class="button button-primary" type="submit">Submit</button></div>'
        . '<div class="clear"></div></div></form>';
    echo '</div>';
}

/* add cron schedules*/
function fbjk_add_cron_schedules($schedules){
  if(!isset($schedules["10seconds"]))
  {
      $schedules["10seconds"] = array( 'interval' => 10,
                                       'display' => __('Once every 10 seconds'));
  }
  return $schedules;
}


/* Executes on deactivation for cleanup*/
function fbjk_deactivate(){
  if(wp_next_scheduled( 'fbjk_fbchecklive_cron_hook' ))
  {
    wp_unschedule_event( wp_next_scheduled( 'fbjk_fbchecklive_cron_hook' ), 'fbjk_fbchecklive_cron_hook' );
  } 
}

/* cron for checking FB live video*/
function fbjk_fbchecklive(){
  if(get_option('fbjk-notificationpageusername') && get_option('fbjk-notificationstatus') && (get_option('fbjk-notificationstatus') == 'enabled'))
  {
    $config = new stdClass();
    $config->pageusername = get_option('fbjk-notificationpageusername');
    $config->videotype = 'live';
    $videos = array();
    $fbreqresponse = loadvideos($config);
    if(is_array($fbreqresponse))
      $videos = $fbreqresponse;
    else
      return $fbreqresponse;
    update_option( 'fbjk-livechecklastexec', time()); 
    if(count($videos))
    {        
      update_option( 'fbjk-livestatus', 'live');         
      return "FB page is live now!";      
    }
    else
    {
      update_option( 'fbjk-livestatus', 'notlive');         
      return "FB page not live!";      
    }      
  }   
}


/* This function creates wp_fbjkembedcodes table at the time of activation*/
function fbjk_install () {
   global $wpdb;
   $table_name = $wpdb->prefix . "fbjkembedcodes"; 
   $charset_collate = $wpdb->get_charset_collate();

    $sql = "CREATE TABLE $table_name (
      id mediumint(9) NOT NULL AUTO_INCREMENT,
      pageusername tinytext NOT NULL,
      videotype tinytext,
      width mediumint(9),
      showdesc tinyint(1),
      allowfullscreen tinyint(1),
      maxrecorded mediumint(9),
      msg text,
      alternatemsg text,
      alternatebehaviour tinytext,
      lastrequest int(15),
      lastrequestresult mediumtext,
      hideiflive tinyint(1),
      usecache tinyint(1),
      cacherefreshtime mediumint(9),
      PRIMARY KEY  (id)
    ) $charset_collate;";

    require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
    dbDelta( $sql );
    update_option( "fbjk_db_version", "2.1" );   
    if(get_option('fbjk-notificationstatus') && (get_option('fbjk-notificationstatus') == 'enabled'))
    {
      if(!wp_next_scheduled( 'fbjk_fbchecklive_cron_hook' ))
      {          
        wp_schedule_event( time(), '10seconds', 'fbjk_fbchecklive_cron_hook' );
      }
    }
}

?>