<?php
/**
 * Functions and definitions
 *
 * @package On Demand
 */

define( 'THEME_VERSION', '4.1.1' );

function ondemand_version_id() {
	if ( WP_DEBUG )
		return time();
	return THEME_VERSION;
}

/**
 * Theme Setup
 *
 */
function ondemand_setup() {

	/**
	 * Custom template tags for this theme.
	 */
	require( get_template_directory() . '/inc/template-tags.php' );

	/**
	 * Custom meta fields
	 */
	require( get_template_directory() . '/inc/meta.php' );

	/**
	 * Custom shortcode functions
	 */
	require( get_template_directory() . '/inc/shortcodes.php' );

	/**
	 * Custom functions that act independently of the theme templates
	 */
	require( get_template_directory() . '/inc/extras.php' );

	/**
	 * Implement theme customizer options
	 */
	require( get_template_directory() . '/inc/customizer.php' );

	// Translation setup
	load_theme_textdomain( 'ondemand', get_template_directory() . '/languages' );

	// Add automatic feed links in header
	add_theme_support( 'automatic-feed-links' );

	// Add support for post formats
	add_theme_support( 'post-formats', array( 'video', 'image' ) );

	// Add Post Thumbnail Image sizes and support
	add_theme_support( 'post-thumbnails' );
    add_image_size( 'grid-item', 360, 240, true );
    add_image_size( 'slider-item', 1170, 540, true );

	// Register custom menus
	register_nav_menus( array(
		'main_menu' => __( 'Main Menu', 'ondemand' )
	));

	// Other WordPress hooks
	add_action( 'pre_get_posts',      'ondemand_main_query_pre_get_posts' );
	add_action( 'wp_enqueue_scripts', 'ondemand_theme_styles' );
	add_action( 'wp_enqueue_scripts', 'ondemand_theme_scripts' );
}

add_action( 'after_setup_theme', 'ondemand_setup' );


/**
 * Implement the Custom Background feature
 */
require( get_template_directory() . '/inc/custom-background.php' );


/**
 * Implement the Custom Header feature
 */
require( get_template_directory() . '/inc/custom-header.php' );

/**
 * Load custom, theme-specific widgets.
 */
require( get_template_directory() . '/inc/widgets.php' );

/**
 * Load widget functionality.
 *
 * @since 1.0.0
 */
function ondemand_setup_widgets() {
	add_action( 'widgets_init', 'ondemand_register_widgets' );
}
add_action( 'after_setup_theme', 'ondemand_setup_widgets' );

/**
 * Register theme-specific widgets.
 *
 * @since 1.0.0
 */
function ondemand_register_widgets() {
	register_widget( 'Ondemand_Widget_Posts' );
}

/**
 * Required Theme Styles
 *
 */
function ondemand_theme_styles() {
	wp_enqueue_style( 'dashicons' );
	wp_enqueue_style( 'ondemand', get_stylesheet_uri(), array(), ondemand_version_id() );
}


/**
 * Required Theme Scripts
 *
 */
function ondemand_theme_scripts() {
	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'ondemand', get_template_directory_uri() . '/assets/js/theme.js', array( 'jquery' ), ondemand_version_id(), true );
	wp_enqueue_script( 'plugins', get_template_directory_uri() . '/assets/js/plugins/plugins-min.js', false, ondemand_version_id(), true );
	
	if( $slideshowSpeed = get_ondemand_option('carousel_autoplay') ) {
		wp_localize_script( 'ondemand', 'slideSpeed', $slideshowSpeed );
	}
	
	if( $slideTransition = get_ondemand_option('carousel_transition') ) {
		wp_localize_script( 'ondemand', 'slideTransition', $slideTransition );
	}
	
	if ( is_front_page() || is_home() || is_page_template('templates/template-slideshow.php') ) {
		wp_enqueue_script( 'carousel', get_template_directory_uri() . '/assets/js/plugins/owl.carousel.min.js', false, ondemand_version_id(), true );
	}
	
	if ( is_page_template('templates/template-portfolio.php') ) {
		wp_enqueue_script( 'isotope', get_template_directory_uri() . '/assets/js/plugins/isotope-min.js', false, ondemand_version_id(), true );
	}
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) && !is_page_template('templates/template-portfolio.php') ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

/**
 * Modify main query to show Category set in Theme Options if set.
 *
 * @param WP_Query $query
 * @return WP_Query
 */
function ondemand_main_query_pre_get_posts( $query ) {	
	// Bail if Home page template, not the home page, not a query, not main query
	if ( ! is_home() || ! is_a( $query, 'WP_Query' ) || ! $query->is_main_query() )
		return;
		
	$query->set( 'cat', get_ondemand_option( 'home_category', null ) );
	$query->set( 'posts_per_page', absint( get_ondemand_option( 'home_category_count', get_option( 'posts_per_page', 9 ) ) ) );
	$query->set( 'paged', ondemand_get_paged_query_var() );
	
}

/**
 * Register widget areas.
 */
function ondemand_register_widget_areas() {
	register_sidebar( array(
		'id'            => 'sidebar-1',
		'name'          => __( 'Sidebar', 'ondemand' ),
		'description'   => __( 'Main sidebar area displayed on right side of page via trigger.', 'ondemand' ),
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h6 class="widget-title">',
		'after_title'   => '</h6>'
	) );
}
add_action( 'widgets_init', 'ondemand_register_widget_areas' );

/**
 * Custom content width for jetpack galleries.
 */
if ( ! isset( $content_width ) )
    $content_width = 714;